#include "Controls.h"
#include "commdlg.h"
#include "CommCtrl.h"

#define CHECKBOX_VALUE_SIZE 32

HWND MakeButton(
    HWND hWindow,
    LPCWSTR name,
    int x,
    int y,
    int width,
    int height
) {
    HWND hwndButton = CreateWindow(
        L"BUTTON",  // Predefined class; Unicode assumed 
        name,      // Button text 
        WS_TABSTOP | WS_VISIBLE | WS_CHILD | BS_DEFPUSHBUTTON,  // Styles 
        x,         // x 
        y,         // y 
        width,        // width
        height,        // height
        hWindow,     // Parent window
        NULL,       // No menu
        (HINSTANCE)GetWindowLongPtr(hWindow, GWLP_HINSTANCE),
        NULL);      // Pointer not needed

    return hwndButton;
}

HWND MakeFilenameTextBox(
    HWND hWindow,
    int x,
    int y,
    int width,
    int height
) {
    HWND hTextbox = CreateWindowEx(
        WS_EX_CLIENTEDGE,
        TEXT("Edit"),
        TEXT("[Run] to start in BASIC, or [Browse] to load a file"),
        WS_CHILD | WS_VISIBLE | WS_VSCROLL | WS_DISABLED | ES_LEFT | ES_MULTILINE | ES_AUTOVSCROLL,
        x,
        y,
        width,
        height,
        hWindow,
        NULL,
        NULL,
        NULL);

    return hTextbox;
}

HWND MakeZoomDropdown(
    HWND hWindow,
    int initiallySelectedIndex,
    int x,
    int y,
    int width,
    int height
) {
    HWND hZoom = CreateWindow(
        WC_COMBOBOX,
        TEXT("Zoom"),
        CBS_DROPDOWN | CBS_HASSTRINGS | WS_CHILD | WS_OVERLAPPED | WS_VISIBLE,
        x, y, width, height,
        hWindow, NULL, NULL, NULL);
    if (!hZoom)
    {
        return hZoom;
    }

    #define NUM_VALUES_ZOOM 9
    TCHAR values[NUM_VALUES_ZOOM][CHECKBOX_VALUE_SIZE] =
    {
        TEXT("1"),
        TEXT("2"),
        TEXT("3"),
        TEXT("4"),
        TEXT("5"),
        TEXT("6"),
        TEXT("7"),
        TEXT("8"),
        TEXT("9")
    };

    TCHAR A[CHECKBOX_VALUE_SIZE];
    memset(&A, 0, sizeof(A));
    for (int k = 0; k < NUM_VALUES_ZOOM; k += 1)
    {
        wcscpy_s(A, sizeof(A) / sizeof(TCHAR), (TCHAR*)values[k]);
        // add string to combobox
        SendMessage(hZoom, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)A);
    }

    SendMessage(hZoom, CB_SETCURSEL, (WPARAM)(initiallySelectedIndex), (LPARAM)0);
    return hZoom;
}

HWND MakeDisplayModeDropdown(
    HWND hWindow,
    int initiallySelectedIndex,
    int x,
    int y,
    int width,
    int height
) {
    HWND h = CreateWindow(
        WC_COMBOBOX,
        TEXT("DisplayMode"),
        CBS_DROPDOWN | CBS_HASSTRINGS | WS_CHILD | WS_OVERLAPPED | WS_VISIBLE,
        x, y, width, height,
        hWindow, NULL, NULL, NULL);
    if (!h)
    {
        return h;
    }

    #define NUM_VALUES_DISPLAY_MODE 3
    TCHAR values[NUM_VALUES_DISPLAY_MODE][CHECKBOX_VALUE_SIZE] =
    {
        TEXT("0 - Windowed"),
        TEXT("1 - Desktop Fullscreen"),
        TEXT("2 - Fullscreen")
    };

    TCHAR A[CHECKBOX_VALUE_SIZE];
    memset(&A, 0, sizeof(A));
    for (int k = 0; k < NUM_VALUES_DISPLAY_MODE; k += 1)
    {
        wcscpy_s(A, sizeof(A) / sizeof(TCHAR), (TCHAR*)values[k]);
        // add string to combobox
        SendMessage(h, (UINT)CB_ADDSTRING, (WPARAM)0, (LPARAM)A);
    }

    SendMessage(h, CB_SETCURSEL, (WPARAM)(initiallySelectedIndex), (LPARAM)0);
    return h;
}

HWND MakeCheckbox(
    HWND hWindow,
    LPCWSTR name,
    HMENU id,
    int x,
    int y,
    int width,
    int height
) {
    HWND hCheckbox = CreateWindow(TEXT("button"), name,
        WS_VISIBLE | WS_CHILD | BS_CHECKBOX | BS_LEFTTEXT,
        x, y, width, height,
        hWindow, id, NULL, NULL);

    return hCheckbox;
}
